(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs'), require('rxjs/operators'), require('@angular/common'), require('@angular/forms')) :
    typeof define === 'function' && define.amd ? define('ngx-headlessui', ['exports', '@angular/core', 'rxjs', 'rxjs/operators', '@angular/common', '@angular/forms'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-headlessui'] = {}, global.ng.core, global.rxjs, global.rxjs.operators, global.ng.common, global.ng.forms));
}(this, (function (exports, core, rxjs, operators, common, forms) { 'use strict';

    function assertNever(x) {
        throw new Error('Unexpected object: ' + x);
    }
    var Focus;
    (function (Focus) {
        /** Focus the first non-disabled item. */
        Focus[Focus["First"] = 0] = "First";
        /** Focus the previous non-disabled item. */
        Focus[Focus["Previous"] = 1] = "Previous";
        /** Focus the next non-disabled item. */
        Focus[Focus["Next"] = 2] = "Next";
        /** Focus the last non-disabled item. */
        Focus[Focus["Last"] = 3] = "Last";
        /** Focus a specific item based on the `id` of the item. */
        Focus[Focus["Specific"] = 4] = "Specific";
        /** Focus no items at all. */
        Focus[Focus["Nothing"] = 5] = "Nothing";
    })(Focus || (Focus = {}));
    ;
    function calculateActiveIndex(action, resolvers) {
        var items = resolvers.resolveItems();
        if (items.length <= 0)
            return null;
        var currentActiveIndex = resolvers.resolveActiveIndex();
        var activeIndex = currentActiveIndex !== null && currentActiveIndex !== void 0 ? currentActiveIndex : -1;
        var nextActiveIndex = (function () {
            switch (action.focus) {
                case Focus.First:
                    return items.findIndex(function (item) { return !resolvers.resolveDisabled(item); });
                case Focus.Previous: {
                    var idx = items
                        .slice()
                        .reverse()
                        .findIndex(function (item, idx, all) {
                        if (activeIndex !== -1 && all.length - idx - 1 >= activeIndex)
                            return false;
                        return !resolvers.resolveDisabled(item);
                    });
                    if (idx === -1)
                        return idx;
                    return items.length - 1 - idx;
                }
                case Focus.Next:
                    return items.findIndex(function (item, idx) {
                        if (idx <= activeIndex)
                            return false;
                        return !resolvers.resolveDisabled(item);
                    });
                case Focus.Last: {
                    var idx = items
                        .slice()
                        .reverse()
                        .findIndex(function (item) { return !resolvers.resolveDisabled(item); });
                    if (idx === -1)
                        return idx;
                    return items.length - 1 - idx;
                }
                case Focus.Specific:
                    return items.findIndex(function (item) { return resolvers.resolveId(item) === action.id; });
                case Focus.Nothing:
                    return null;
                default:
                    assertNever(action);
            }
        })();
        return nextActiveIndex === -1 ? currentActiveIndex : nextActiveIndex;
    }

    // TODO: This must already exist somewhere, right? 🤔
    // Ref: https://www.w3.org/TR/uievents-key/#named-key-attribute-values
    var Keys;
    (function (Keys) {
        Keys["Space"] = " ";
        Keys["Enter"] = "Enter";
        Keys["Escape"] = "Escape";
        Keys["Backspace"] = "Backspace";
        Keys["ArrowUp"] = "ArrowUp";
        Keys["ArrowDown"] = "ArrowDown";
        Keys["Home"] = "Home";
        Keys["End"] = "End";
        Keys["PageUp"] = "PageUp";
        Keys["PageDown"] = "PageDown";
        Keys["Tab"] = "Tab";
    })(Keys || (Keys = {}));
    ;

    var id = 0;
    function generateId() {
        return ++id;
    }
    function useId() {
        return generateId();
    }

    (function (MenuStates) {
        MenuStates[MenuStates["Closed"] = 0] = "Closed";
        MenuStates[MenuStates["Open"] = 1] = "Open";
    })(exports.MenuStates || (exports.MenuStates = {}));
    ;

    var MenuComponent = /** @class */ (function () {
        function MenuComponent(elementRef) {
            this.elementRef = elementRef;
            this.static = false;
            this.menuState = new rxjs.BehaviorSubject(exports.MenuStates.Closed);
            this.buttonRef = null;
            this.itemsRef = null;
            this.items = [];
            this.searchQuery = '';
            this.activeItemIndex = null;
        }
        MenuComponent.prototype.closeMenu = function () {
            this.menuState.next(exports.MenuStates.Closed);
            this.activeItemIndex = null;
        };
        MenuComponent.prototype.openMenu = function () {
            this.menuState.next(exports.MenuStates.Open);
        };
        MenuComponent.prototype.isOpened = function () {
            return this.menuState && this.menuState.value === exports.MenuStates.Open;
        };
        MenuComponent.prototype.goToItem = function (focus, id) {
            var _this = this;
            var nextActiveItemIndex = calculateActiveIndex(focus === Focus.Specific ? { focus: Focus.Specific, id: id } : { focus: focus }, {
                resolveItems: function () { return _this.items; },
                resolveActiveIndex: function () { return _this.activeItemIndex; },
                resolveId: function (item) { return item.id; },
                resolveDisabled: function (item) { return item.dataRef.disabled; },
            });
            if (this.searchQuery === '' && this.activeItemIndex === nextActiveItemIndex)
                return;
            this.searchQuery = '';
            this.activeItemIndex = nextActiveItemIndex;
            var elementId = null;
            if (this.activeItemIndex !== null) {
                elementId = this.items[this.activeItemIndex].id;
            }
        };
        MenuComponent.prototype.search = function (value) {
            var _this = this;
            this.searchQuery += value;
            var match = this.items.findIndex(function (item) { return item.dataRef.textValue.startsWith(_this.searchQuery) && !item.dataRef.disabled; });
            if (match === -1 || match === this.activeItemIndex)
                return;
            this.activeItemIndex = match;
        };
        MenuComponent.prototype.clearSearch = function () {
            this.searchQuery = '';
        };
        MenuComponent.prototype.registerItem = function (id, dataRef) {
            this.items.push({ id: id, dataRef: dataRef });
        };
        MenuComponent.prototype.unregisterItem = function (id) {
            var _this = this;
            var nextItems = this.items.slice();
            var currentActiveItem = this.activeItemIndex !== null ? nextItems[this.activeItemIndex] : null;
            var idx = nextItems.findIndex(function (a) { return a.id === id; });
            if (idx !== -1)
                nextItems.splice(idx, 1);
            this.items = nextItems;
            this.activeItemIndex = (function () {
                if (idx === _this.activeItemIndex)
                    return null;
                if (currentActiveItem === null)
                    return null;
                // If we removed the item before the actual active index, then it would be out of sync. To
                // fix this, we will find the correct (new) index position.
                return nextItems.indexOf(currentActiveItem);
            })();
        };
        MenuComponent.prototype.handler = function (event) {
            var _a, _b, _c;
            var target = event.target;
            var active = document.activeElement;
            if (this.menuState.value !== exports.MenuStates.Open)
                return;
            if ((_a = this.buttonRef) === null || _a === void 0 ? void 0 : _a.contains(target))
                return;
            if (!((_b = this.elementRef.nativeElement) === null || _b === void 0 ? void 0 : _b.contains(target)))
                this.closeMenu();
            if (active !== document.body && (active === null || active === void 0 ? void 0 : active.contains(target)))
                return; // Keep focus on newly clicked/focused element
            if (!event.defaultPrevented)
                (_c = this.buttonRef) === null || _c === void 0 ? void 0 : _c.focus({ preventScroll: true });
        };
        return MenuComponent;
    }());
    MenuComponent.decorators = [
        { type: core.Component, args: [{
                    selector: '[Menu], [HeadlessMenu]',
                    template: "<ng-content></ng-content>"
                },] }
    ];
    MenuComponent.ctorParameters = function () { return [
        { type: core.ElementRef }
    ]; };
    MenuComponent.propDecorators = {
        static: [{ type: core.Input }],
        handler: [{ type: core.HostListener, args: ['window:click', ['$event'],] }]
    };

    function nextFrame(cb) {
        requestAnimationFrame(function () { return requestAnimationFrame(cb); });
    }
    var MenuButtonDirective = /** @class */ (function () {
        function MenuButtonDirective(menu, elementRef) {
            this.menu = menu;
            this.elementRef = elementRef;
            this.disabled = false;
            this.id = "headlessui-menu-button-" + useId();
        }
        MenuButtonDirective.prototype.ngAfterViewInit = function () {
            this.menu.buttonRef = this.elementRef.nativeElement;
        };
        MenuButtonDirective.prototype.isOpen = function () {
            return this.menu.menuState.value === exports.MenuStates.Open ? true : undefined;
        };
        MenuButtonDirective.prototype.handleKeyDown = function (event) {
            var _this = this;
            switch (event.key) {
                // Ref: https://www.w3.org/TR/wai-aria-practices-1.2/#keyboard-interaction-13
                case Keys.Space:
                case Keys.Enter:
                case Keys.ArrowDown:
                    event.preventDefault();
                    this.menu.openMenu();
                    setTimeout(function () {
                        var _a;
                        (_a = _this.menu.itemsRef) === null || _a === void 0 ? void 0 : _a.focus({ preventScroll: true });
                        _this.menu.goToItem(Focus.First);
                    });
                    break;
                case Keys.ArrowUp:
                    event.preventDefault();
                    this.menu.openMenu();
                    setTimeout(function () {
                        var _a;
                        (_a = _this.menu.itemsRef) === null || _a === void 0 ? void 0 : _a.focus({ preventScroll: true });
                        _this.menu.goToItem(Focus.Last);
                    });
                    break;
            }
        };
        MenuButtonDirective.prototype.handlePointerUp = function (event) {
            var _this = this;
            if (this.disabled)
                return;
            if (this.menu.isOpened()) {
                this.menu.closeMenu();
                setTimeout(function () { var _a; return (_a = _this.menu.buttonRef) === null || _a === void 0 ? void 0 : _a.focus({ preventScroll: true }); });
            }
            else {
                event.preventDefault();
                this.menu.openMenu();
                nextFrame(function () { var _a; return (_a = _this.menu.itemsRef) === null || _a === void 0 ? void 0 : _a.focus({ preventScroll: true }); });
            }
        };
        return MenuButtonDirective;
    }());
    MenuButtonDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[MenuButton], [HeadlessMenuButton]',
                    host: {
                        '[attr.id]': 'id',
                        '[attr.type]': '"button"',
                        '[attr.aria-haspopup]': 'true',
                        // '[attr.aria-controls]': 'menu.itemsRef.id',
                        '[attr.aria-expanded]': 'isOpen()',
                    }
                },] }
    ];
    MenuButtonDirective.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core.Inject, args: [core.forwardRef(function () { return MenuComponent; }),] }] },
        { type: core.ElementRef }
    ]; };
    MenuButtonDirective.propDecorators = {
        disabled: [{ type: core.Input }],
        handleKeyDown: [{ type: core.HostListener, args: ['keydown', ['$event'],] }],
        handlePointerUp: [{ type: core.HostListener, args: ['pointerup', ['$event'],] }]
    };

    var MenuItemComponent = /** @class */ (function () {
        function MenuItemComponent(menu, elementRef) {
            this.menu = menu;
            this.elementRef = elementRef;
            this.id = "headlessui-menu-item-" + useId();
            this.dataRef = { textValue: '', disabled: this._disabled };
        }
        Object.defineProperty(MenuItemComponent.prototype, "disabled", {
            set: function (value) {
                if (value || value === '') {
                    this._disabled = true;
                }
                else {
                    this._disabled = false;
                }
            },
            enumerable: false,
            configurable: true
        });
        MenuItemComponent.prototype.ngOnDestroy = function () {
            this.menu.unregisterItem(this.id);
        };
        MenuItemComponent.prototype.ngAfterViewInit = function () {
            var _a, _b;
            var textValue = (_b = (_a = this.elementRef.nativeElement) === null || _a === void 0 ? void 0 : _a.textContent) === null || _b === void 0 ? void 0 : _b.toLowerCase().trim();
            if (textValue !== undefined)
                this.dataRef.textValue = textValue;
            this.menu.registerItem(this.id, this.dataRef);
        };
        Object.defineProperty(MenuItemComponent.prototype, "active", {
            get: function () {
                return this.menu.activeItemIndex !== null ? this.menu.items[this.menu.activeItemIndex].id === this.id : false;
            },
            enumerable: false,
            configurable: true
        });
        MenuItemComponent.prototype.handleClick = function (event) {
            var _this = this;
            if (this.disabled)
                return event.preventDefault();
            this.menu.closeMenu();
            setTimeout(function () { var _a; return (_a = _this.menu.buttonRef) === null || _a === void 0 ? void 0 : _a.focus({ preventScroll: true }); });
        };
        MenuItemComponent.prototype.handleFocus = function () {
            if (this.disabled)
                return this.menu.goToItem(Focus.Nothing);
            this.menu.goToItem(Focus.Specific, this.id);
        };
        MenuItemComponent.prototype.handlePointerMove = function () {
            if (this.disabled)
                return;
            if (this.active)
                return;
            this.menu.goToItem(Focus.Specific, this.id);
        };
        MenuItemComponent.prototype.handlePointerLeave = function () {
            if (this.disabled)
                return;
            if (!this.active)
                return;
            this.menu.goToItem(Focus.Nothing);
        };
        return MenuItemComponent;
    }());
    MenuItemComponent.decorators = [
        { type: core.Component, args: [{
                    selector: '[MenuItem], [HeadlessMenuItem]',
                    host: {
                        '[attr.id]': 'id',
                        '[attr.role]': '"menuitem"',
                        '[attr.tabIndex]': '"-1"',
                        '[attr.aria-disabled]': '_disabled === true ? true : undefined'
                    },
                    template: "\n    <ng-template [ngTemplateOutlet]=\"template\" [ngTemplateOutletContext]=\"{$implicit: dataRef, 'active': active, 'disabled': _disabled}\"></ng-template>\n    <ng-content></ng-content>\n  "
                },] }
    ];
    MenuItemComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core.Inject, args: [core.forwardRef(function () { return MenuComponent; }),] }] },
        { type: core.ElementRef }
    ]; };
    MenuItemComponent.propDecorators = {
        template: [{ type: core.ContentChild, args: [core.TemplateRef,] }],
        disabled: [{ type: core.Input }],
        handleClick: [{ type: core.HostListener, args: ['click', ['$event'],] }],
        handleFocus: [{ type: core.HostListener, args: ['focus',] }],
        handlePointerMove: [{ type: core.HostListener, args: ['pointermove',] }],
        handlePointerLeave: [{ type: core.HostListener, args: ['pointerleave',] }]
    };

    var MenuItemsDirective = /** @class */ (function () {
        function MenuItemsDirective(menu, templateRef, viewContainer, renderer) {
            this.menu = menu;
            this.templateRef = templateRef;
            this.viewContainer = viewContainer;
            this.renderer = renderer;
            this.id = "headlessui-menu-items-" + useId();
            this.searchDebounce = null;
        }
        MenuItemsDirective.prototype.ngAfterViewInit = function () {
            if (this.menu.static) {
                this.setAttributes();
            }
        };
        MenuItemsDirective.prototype.ngOnInit = function () {
            var _this = this;
            if (this.menu.static) {
                this.embedTemplate();
                return;
            }
            this.menu.menuState.pipe(operators.distinctUntilChanged()).subscribe(function (menuState) {
                _this.hide();
                if (menuState === exports.MenuStates.Open) {
                    _this.show();
                }
            });
        };
        MenuItemsDirective.prototype.show = function () {
            // If the menu is static don't modify anything let the user modify it's state
            if (this.menu.static) {
                return;
            }
            this.embedTemplate();
            this.setAttributes();
        };
        MenuItemsDirective.prototype.hide = function () {
            // If the menu is static don't modify anything let the user modify it's state
            if (this.menu.static) {
                return;
            }
            this.viewContainer.clear();
        };
        MenuItemsDirective.prototype.embedTemplate = function () {
            var view = this.viewContainer.createEmbeddedView(this.templateRef);
            this.elementRef = view.rootNodes[0];
            this.menu.itemsRef = this.elementRef;
        };
        MenuItemsDirective.prototype.setAttributes = function () {
            var _this = this;
            var _a, _b;
            this.renderer.setAttribute(this.elementRef, 'aria-activedescendant', "" + (this.menu.activeItemIndex === null ? undefined : (_a = this.menu.items[this.menu.activeItemIndex]) === null || _a === void 0 ? void 0 : _a.id));
            this.renderer.setAttribute(this.elementRef, 'aria-labelledby', "" + ((_b = this.menu.buttonRef) === null || _b === void 0 ? void 0 : _b.id));
            this.renderer.setAttribute(this.elementRef, 'id', this.id);
            this.renderer.setAttribute(this.elementRef, 'role', 'menu');
            this.renderer.setAttribute(this.elementRef, 'tabIndex', '0');
            rxjs.fromEvent(this.elementRef, 'keydown').subscribe(function (event) {
                var _a;
                if (_this.searchDebounce)
                    clearTimeout(_this.searchDebounce);
                switch (event.key) {
                    // Ref: https://www.w3.org/TR/wai-aria-practices-1.2/#keyboard-interaction-12
                    // @ts-expect-error Fallthrough is expected here
                    case Keys.Space:
                        if (_this.menu.searchQuery !== '') {
                            event.preventDefault();
                            return _this.menu.search(event.key);
                        }
                    // When in type ahead mode, fallthrough
                    case Keys.Enter:
                        event.preventDefault();
                        if (_this.menu.activeItemIndex !== null) {
                            var id = _this.menu.items[_this.menu.activeItemIndex].id;
                            (_a = document.getElementById(id)) === null || _a === void 0 ? void 0 : _a.click();
                        }
                        _this.menu.closeMenu();
                        setTimeout(function () { var _a; return (_a = _this.menu.buttonRef) === null || _a === void 0 ? void 0 : _a.focus({ preventScroll: true }); });
                        break;
                    case Keys.ArrowDown:
                        event.preventDefault();
                        return _this.menu.goToItem(Focus.Next);
                    case Keys.ArrowUp:
                        event.preventDefault();
                        return _this.menu.goToItem(Focus.Previous);
                    case Keys.Home:
                    case Keys.PageUp:
                        event.preventDefault();
                        return _this.menu.goToItem(Focus.First);
                    case Keys.End:
                    case Keys.PageDown:
                        event.preventDefault();
                        return _this.menu.goToItem(Focus.Last);
                    case Keys.Escape:
                        event.preventDefault();
                        _this.menu.closeMenu();
                        setTimeout(function () { var _a; return (_a = _this.menu.buttonRef) === null || _a === void 0 ? void 0 : _a.focus({ preventScroll: true }); });
                        break;
                    case Keys.Tab:
                        return event.preventDefault();
                    default:
                        if (event.key.length === 1) {
                            _this.menu.search(event.key);
                            _this.searchDebounce = setTimeout(function () { return _this.menu.clearSearch(); }, 350);
                        }
                        break;
                }
            });
        };
        return MenuItemsDirective;
    }());
    MenuItemsDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[MenuItems], [HeadlessMenuItems]',
                },] }
    ];
    MenuItemsDirective.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core.Inject, args: [core.forwardRef(function () { return MenuComponent; }),] }] },
        { type: core.TemplateRef },
        { type: core.ViewContainerRef },
        { type: core.Renderer2 }
    ]; };

    var MenuModule = /** @class */ (function () {
        function MenuModule() {
        }
        return MenuModule;
    }());
    MenuModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [
                        MenuComponent,
                        MenuItemsDirective,
                        MenuItemComponent,
                        MenuButtonDirective
                    ],
                    imports: [
                        common.CommonModule
                    ],
                    exports: [
                        MenuComponent,
                        MenuItemsDirective,
                        MenuItemComponent,
                        MenuButtonDirective
                    ],
                },] }
    ];

    var SwitchGroupDirective = /** @class */ (function () {
        function SwitchGroupDirective() {
            this.dataRef = { switchRef: null, labelRef: null, descriptionRef: null };
        }
        return SwitchGroupDirective;
    }());
    SwitchGroupDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[ngx-switch-group], [switch-group], [SwitchGroup]',
                },] }
    ];
    SwitchGroupDirective.ctorParameters = function () { return []; };

    var SwitchDescriptionDirective = /** @class */ (function () {
        function SwitchDescriptionDirective(switchGroup, elementRef) {
            this.switchGroup = switchGroup;
            this.id = "headlessui-switch-description-" + useId();
            this.switchGroup.dataRef.labelRef = elementRef.nativeElement;
        }
        SwitchDescriptionDirective.prototype.handlePointerUp = function () {
            var _a, _b;
            (_a = this.switchGroup.dataRef.switchRef) === null || _a === void 0 ? void 0 : _a.click();
            (_b = this.switchGroup.dataRef.switchRef) === null || _b === void 0 ? void 0 : _b.focus({ preventScroll: true });
        };
        return SwitchDescriptionDirective;
    }());
    SwitchDescriptionDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[ngx-switch-description], [switch-description], [SwitchDescription]',
                    host: {
                        '[attr.id]': 'id'
                    }
                },] }
    ];
    SwitchDescriptionDirective.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core.Inject, args: [core.forwardRef(function () { return SwitchGroupDirective; }),] }] },
        { type: core.ElementRef }
    ]; };
    SwitchDescriptionDirective.propDecorators = {
        handlePointerUp: [{ type: core.HostListener, args: ['pointerup',] }]
    };

    var SwitchLabelDirective = /** @class */ (function () {
        function SwitchLabelDirective(switchGroup, elementRef) {
            this.switchGroup = switchGroup;
            this.id = "headlessui-switch-label-" + useId();
            this.switchGroup.dataRef.labelRef = elementRef.nativeElement;
        }
        SwitchLabelDirective.prototype.handlePointerUp = function () {
            var _a, _b;
            (_a = this.switchGroup.dataRef.switchRef) === null || _a === void 0 ? void 0 : _a.click();
            (_b = this.switchGroup.dataRef.switchRef) === null || _b === void 0 ? void 0 : _b.focus({ preventScroll: true });
        };
        return SwitchLabelDirective;
    }());
    SwitchLabelDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[ngx-switch-label], [switch-label], [SwitchLabel]',
                    host: {
                        '[attr.id]': 'id'
                    }
                },] }
    ];
    SwitchLabelDirective.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core.Inject, args: [core.forwardRef(function () { return SwitchGroupDirective; }),] }] },
        { type: core.ElementRef }
    ]; };
    SwitchLabelDirective.propDecorators = {
        handlePointerUp: [{ type: core.HostListener, args: ['pointerup',] }]
    };

    var SwitchComponent = /** @class */ (function () {
        function SwitchComponent(switchGroup, elementRef) {
            this.switchGroup = switchGroup;
            this.id = "headlessui-switch-" + useId();
            this.value = false;
            this.change = new core.EventEmitter();
            this.propagateChange = function (_) { };
            this.switchGroup.dataRef.switchRef = elementRef.nativeElement;
        }
        SwitchComponent.prototype.toggle = function () {
            this.value = !this.value;
            this.change.emit(this.value);
        };
        SwitchComponent.prototype.handleClick = function (event) {
            event.preventDefault();
            this.toggle();
        };
        SwitchComponent.prototype.handleKeyUp = function (event) {
            if (event.key !== Keys.Tab)
                event.preventDefault();
            if (event.key === Keys.Space)
                this.toggle();
        };
        SwitchComponent.prototype.handleKeyPress = function (event) {
            event.preventDefault();
        };
        SwitchComponent.prototype.writeValue = function (obj) {
            this.value = obj;
        };
        SwitchComponent.prototype.registerOnChange = function (fn) {
            this.propagateChange = fn;
        };
        SwitchComponent.prototype.registerOnTouched = function (fn) {
        };
        return SwitchComponent;
    }());
    SwitchComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ngx-switch, switch, [Switch]',
                    template: "<ng-template [ngTemplateOutlet]=\"templateRef\" [ngTemplateOutletContext]=\"{'checked': value}\"></ng-template>\n<ng-content></ng-content>\n",
                    host: {
                        '[attr.id]': 'id',
                        '[attr.role]': '"switch"',
                        '[attr.tabIndex]': '0',
                        '[attr.aria-checked]': 'value',
                        '[attr.aria-labelledby]': 'switchGroup.dataRef.labelRef?.id',
                        '[attr.aria-describedby]': 'switchGroup.dataRef.descriptionRef?.id',
                    },
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return SwitchComponent; }),
                            multi: true
                        }
                    ]
                },] }
    ];
    SwitchComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core.Inject, args: [core.forwardRef(function () { return SwitchGroupDirective; }),] }] },
        { type: core.ElementRef }
    ]; };
    SwitchComponent.propDecorators = {
        templateRef: [{ type: core.ContentChild, args: [core.TemplateRef,] }],
        change: [{ type: core.Output }],
        handleClick: [{ type: core.HostListener, args: ['click', ['$event'],] }],
        handleKeyUp: [{ type: core.HostListener, args: ['onkeyup', ['$event'],] }],
        handleKeyPress: [{ type: core.HostListener, args: ['onkeydown', ['$event'],] }]
    };

    var SwitchModule = /** @class */ (function () {
        function SwitchModule() {
        }
        return SwitchModule;
    }());
    SwitchModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [SwitchComponent, SwitchGroupDirective, SwitchLabelDirective, SwitchDescriptionDirective],
                    imports: [
                        common.CommonModule
                    ],
                    exports: [SwitchComponent, SwitchGroupDirective, SwitchLabelDirective, SwitchDescriptionDirective]
                },] }
    ];

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        return extendStatics(d, b);
    };
    function __extends(d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    var __assign = function () {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function __rest(s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }
    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
            r = Reflect.decorate(decorators, target, key, desc);
        else
            for (var i = decorators.length - 1; i >= 0; i--)
                if (d = decorators[i])
                    r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); };
    }
    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
            return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try {
                step(generator.next(value));
            }
            catch (e) {
                reject(e);
            } }
            function rejected(value) { try {
                step(generator["throw"](value));
            }
            catch (e) {
                reject(e);
            } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }
    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function () { if (t[0] & 1)
                throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f)
                throw new TypeError("Generator is already executing.");
            while (_)
                try {
                    if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                        return t;
                    if (y = 0, t)
                        op = [op[0] & 2, t.value];
                    switch (op[0]) {
                        case 0:
                        case 1:
                            t = op;
                            break;
                        case 4:
                            _.label++;
                            return { value: op[1], done: false };
                        case 5:
                            _.label++;
                            y = op[1];
                            op = [0];
                            continue;
                        case 7:
                            op = _.ops.pop();
                            _.trys.pop();
                            continue;
                        default:
                            if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                _ = 0;
                                continue;
                            }
                            if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                _.label = op[1];
                                break;
                            }
                            if (op[0] === 6 && _.label < t[1]) {
                                _.label = t[1];
                                t = op;
                                break;
                            }
                            if (t && _.label < t[2]) {
                                _.label = t[2];
                                _.ops.push(op);
                                break;
                            }
                            if (t[2])
                                _.ops.pop();
                            _.trys.pop();
                            continue;
                    }
                    op = body.call(thisArg, _);
                }
                catch (e) {
                    op = [6, e];
                    y = 0;
                }
                finally {
                    f = t = 0;
                }
            if (op[0] & 5)
                throw op[1];
            return { value: op[0] ? op[1] : void 0, done: true };
        }
    }
    var __createBinding = Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        Object.defineProperty(o, k2, { enumerable: true, get: function () { return m[k]; } });
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    });
    function __exportStar(m, o) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                __createBinding(o, m, p);
    }
    function __values(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m)
            return m.call(o);
        if (o && typeof o.length === "number")
            return {
                next: function () {
                    if (o && i >= o.length)
                        o = void 0;
                    return { value: o && o[i++], done: !o };
                }
            };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m)
            return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                ar.push(r.value);
        }
        catch (error) {
            e = { error: error };
        }
        finally {
            try {
                if (r && !r.done && (m = i["return"]))
                    m.call(i);
            }
            finally {
                if (e)
                    throw e.error;
            }
        }
        return ar;
    }
    /** @deprecated */
    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }
    /** @deprecated */
    function __spreadArrays() {
        for (var s = 0, i = 0, il = arguments.length; i < il; i++)
            s += arguments[i].length;
        for (var r = Array(s), k = 0, i = 0; i < il; i++)
            for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
        return r;
    }
    function __spreadArray(to, from) {
        for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
            to[j] = from[i];
        return to;
    }
    function __await(v) {
        return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var g = generator.apply(thisArg, _arguments || []), i, q = [];
        return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
        function verb(n) { if (g[n])
            i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
        function resume(n, v) { try {
            step(g[n](v));
        }
        catch (e) {
            settle(q[0][3], e);
        } }
        function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
        function fulfill(value) { resume("next", value); }
        function reject(value) { resume("throw", value); }
        function settle(f, v) { if (f(v), q.shift(), q.length)
            resume(q[0][0], q[0][1]); }
    }
    function __asyncDelegator(o) {
        var i, p;
        return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
        function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
    }
    function __asyncValues(o) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var m = o[Symbol.asyncIterator], i;
        return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
        function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
        function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
    }
    function __makeTemplateObject(cooked, raw) {
        if (Object.defineProperty) {
            Object.defineProperty(cooked, "raw", { value: raw });
        }
        else {
            cooked.raw = raw;
        }
        return cooked;
    }
    ;
    var __setModuleDefault = Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    };
    function __importStar(mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    }
    function __importDefault(mod) {
        return (mod && mod.__esModule) ? mod : { default: mod };
    }
    function __classPrivateFieldGet(receiver, privateMap) {
        if (!privateMap.has(receiver)) {
            throw new TypeError("attempted to get private field on non-instance");
        }
        return privateMap.get(receiver);
    }
    function __classPrivateFieldSet(receiver, privateMap, value) {
        if (!privateMap.has(receiver)) {
            throw new TypeError("attempted to set private field on non-instance");
        }
        privateMap.set(receiver, value);
        return value;
    }

    /**
     * Credit: https://github.com/tailwindlabs/headlessui/
     */
    function disposables() {
        var disposables = [];
        var api = {
            requestAnimationFrame: function () {
                var args = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    args[_i] = arguments[_i];
                }
                var raf = requestAnimationFrame.apply(void 0, __spread(args));
                api.add(function () { return cancelAnimationFrame(raf); });
            },
            nextFrame: function () {
                var args = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    args[_i] = arguments[_i];
                }
                api.requestAnimationFrame(function () {
                    api.requestAnimationFrame.apply(api, __spread(args));
                });
            },
            setTimeout: function () {
                var args = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    args[_i] = arguments[_i];
                }
                var timer = setTimeout.apply(void 0, __spread(args));
                api.add(function () { return clearTimeout(timer); });
            },
            add: function (cb) {
                disposables.push(cb);
            },
            dispose: function () {
                disposables.splice(0).forEach(function (dispose) { return dispose(); });
            },
        };
        return api;
    }

    /**
     * Credit: https://github.com/tailwindlabs/headlessui/
     */
    function once(cb) {
        var state = { called: false };
        return function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            if (state.called) {
                return;
            }
            state.called = true;
            return cb.apply(void 0, __spread(args));
        };
    }

    function addClasses(node) {
        var _a;
        var classes = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            classes[_i - 1] = arguments[_i];
        }
        node && classes.length > 0 && (_a = node.classList).add.apply(_a, __spread(classes));
    }
    function removeClasses(node) {
        var _a;
        var classes = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            classes[_i - 1] = arguments[_i];
        }
        node && classes.length > 0 && (_a = node.classList).remove.apply(_a, __spread(classes));
    }
    (function (Reason) {
        Reason["Finished"] = "finished";
        Reason["Cancelled"] = "cancelled";
    })(exports.Reason || (exports.Reason = {}));
    function waitForTransition(node, done) {
        var d = disposables();
        if (!node)
            return d.dispose;
        // Safari returns a comma separated list of values, so let's sort them and take the highest value.
        var _a = getComputedStyle(node), transitionDuration = _a.transitionDuration, transitionDelay = _a.transitionDelay;
        var _b = __read([transitionDuration, transitionDelay].map(function (value) {
            var _a = __read(value
                .split(',')
                // Remove falseys we can't work with
                .filter(Boolean)
                // Values are returned as `0.3s` or `75ms`
                .map(function (v) { return (v.includes('ms') ? parseFloat(v) : parseFloat(v) * 1000); })
                .sort(function (a, z) { return z - a; }), 1), _b = _a[0], resolvedValue = _b === void 0 ? 0 : _b;
            return resolvedValue;
        }), 2), durationMs = _b[0], delaysMs = _b[1];
        // Waiting for the transition to end. We could use the `transitionend` event, however when no
        // actual transition/duration is defined then the `transitionend` event is not fired.
        //
        // TODO: Downside is, when you slow down transitions via devtools this timeout is still using the
        // full 100% speed instead of the 25% or 10%.
        if (durationMs !== 0) {
            d.setTimeout(function () {
                done(exports.Reason.Finished);
            }, durationMs + delaysMs);
        }
        else {
            // No transition is happening, so we should cleanup already. Otherwise we have to wait until we
            // get disposed.
            done(exports.Reason.Finished);
        }
        // If we get disposed before the timeout runs we should cleanup anyway
        d.add(function () { return done(exports.Reason.Cancelled); });
        return d.dispose;
    }
    function transition(node, base, from, to, done) {
        var d = disposables();
        var _done = done !== undefined ? once(done) : function () { };
        addClasses.apply(void 0, __spread([node], base, from));
        d.nextFrame(function () {
            removeClasses.apply(void 0, __spread([node], from));
            addClasses.apply(void 0, __spread([node], to));
            d.add(waitForTransition(node, function (reason) {
                removeClasses.apply(void 0, __spread([node], to, base));
                return _done(reason);
            }));
        });
        // Once we get disposed, we should ensure that we cleanup after ourselves. In case of an unmount,
        // the node itself will be nullified and will be a no-op. In case of a full transition the classes
        // are already removed which is also a no-op. However if you go from enter -> leave mid-transition
        // then we have some leftovers that should be cleaned.
        d.add(function () { return removeClasses.apply(void 0, __spread([node], base, from, to)); });
        // When we get disposed early, than we should also call the done method but switch the reason.
        d.add(function () { return _done(exports.Reason.Cancelled); });
        return d.dispose;
    }

    var TransitionComponent = /** @class */ (function () {
        function TransitionComponent() {
            this._children = new core.QueryList();
            this._show = new rxjs.BehaviorSubject(false);
            /**
             * Classes to be applied on the element when showing
             */
            this.enter = '';
            this.enterFrom = '';
            this.enterTo = '';
            /**
             * Classes to be applied on the element when leaving
             */
            this.leave = '';
            this.leaveFrom = '';
            this.leaveTo = '';
            this.beforeEnter = new core.EventEmitter();
            this.afterEnter = new core.EventEmitter();
            this.beforeLeave = new core.EventEmitter();
            this.afterLeave = new core.EventEmitter();
            this.closed = true;
            this._init = true;
        }
        Object.defineProperty(TransitionComponent.prototype, "show", {
            get: function () {
                return this._show.value;
            },
            /**
             * Whether to show or not the contents of ngx-transition
             */
            set: function (value) {
                this._show.next(value);
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(TransitionComponent.prototype, "getDisplay", {
            get: function () {
                return this._init ? 'none' : '';
            },
            enumerable: false,
            configurable: true
        });
        TransitionComponent.prototype.ngOnInit = function () {
            var _this = this;
            this.closed = !this.show;
            if (this.closed) {
                this._init = true;
                if (this.closed) {
                    this.closed = false;
                    setTimeout(function () {
                        _this._elementRef = _this._getElement();
                        _this.closed = true;
                    });
                }
            }
            else {
                setTimeout(function () {
                    _this._elementRef = _this._getElement();
                    _this._updateView();
                });
            }
            this._show.pipe(operators.skip(1)).subscribe(function () {
                _this._updateView();
            });
        };
        TransitionComponent.prototype._updateView = function () {
            return __awaiter(this, void 0, void 0, function () {
                var childrenFinished_1, _a, _b, child;
                var e_1, _c;
                var _this = this;
                return __generator(this, function (_d) {
                    if (this.show) {
                        this.closed = false;
                        this._transitionEnter();
                    }
                    else {
                        if (this._children.length > 0) {
                            childrenFinished_1 = new rxjs.BehaviorSubject(0);
                            try {
                                for (_a = __values(this._children.toArray().reverse()), _b = _a.next(); !_b.done; _b = _a.next()) {
                                    child = _b.value;
                                    child.afterLeave.pipe(operators.first()).subscribe(function () {
                                        childrenFinished_1.pipe(operators.first()).subscribe(function (value) {
                                            childrenFinished_1.next(++value);
                                        });
                                    });
                                    child.show = false;
                                }
                            }
                            catch (e_1_1) { e_1 = { error: e_1_1 }; }
                            finally {
                                try {
                                    if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                                }
                                finally { if (e_1) throw e_1.error; }
                            }
                            childrenFinished_1.subscribe(function (value) {
                                if (value === _this._children.length)
                                    _this._transitionLeave();
                            });
                        }
                        else {
                            this._transitionLeave();
                        }
                    }
                    return [2 /*return*/];
                });
            });
        };
        TransitionComponent.prototype._getElement = function () {
            if (!this._elementRef) {
                this._elementRef = this._viewContainer.get(0).rootNodes.find(function (element) { return element.tagName; });
                this._init = false;
            }
            return this._elementRef;
        };
        TransitionComponent.prototype._transitionEnter = function () {
            var _this = this;
            this.beforeEnter.emit();
            transition(this._getElement(), this._useSplitClasses(this.enter), this._useSplitClasses(this.enterFrom), this._useSplitClasses(this.enterTo), function (reason) {
                _this.afterEnter.emit();
                if (_this._children.length > 0) {
                    _this._children.forEach(function (child) {
                        child.show = true;
                    });
                }
            });
        };
        TransitionComponent.prototype._transitionLeave = function () {
            var _this = this;
            this.beforeLeave.emit();
            transition(this._getElement(), this._useSplitClasses(this.leave), this._useSplitClasses(this.leaveFrom), this._useSplitClasses(this.leaveTo), function (reason) {
                _this.afterLeave.emit();
                _this.closed = true;
            });
        };
        TransitionComponent.prototype._useSplitClasses = function (classes) {
            if (classes === void 0) { classes = ''; }
            return classes.split(' ').filter(function (className) { return className.trim().length > 1; });
        };
        return TransitionComponent;
    }());
    TransitionComponent.decorators = [
        { type: core.Component, args: [{
                    selector: '[ngx-transition], [transition], transition, ngx-transition',
                    template: "<!--\r\n\r\n    <ngx-transition [show]=\"true\"\r\n    [enter]=\"'transition ease-out duration-100'\"\r\n    [enterFrom]=\"'transform opacity-0 scale-95'\"\r\n    [enterTo]=\"'transform opacity-100 scale-100'\"\r\n    [leave]=\"'transition ease-in duration-75'\"\r\n    [leaveFrom]=\"'transform opacity-100 scale-100'\"\r\n    [leaveTo]=\"'transform opacity-0 scale-95'\">\r\n\r\n    </ngx-transition>\r\n\r\n-->\r\n<ng-template #transitionTemplate>\r\n   <ng-content></ng-content>\r\n</ng-template>\r\n\r\n<ng-container #transitionContainer [ngTemplateOutlet]=\"closed ? null : transitionTemplate\"></ng-container>\r\n"
                },] }
    ];
    TransitionComponent.ctorParameters = function () { return []; };
    TransitionComponent.propDecorators = {
        _children: [{ type: core.ContentChildren, args: [TransitionComponent, { descendants: true },] }],
        _viewContainer: [{ type: core.ViewChild, args: ['transitionContainer', { read: core.ViewContainerRef, static: true },] }],
        show: [{ type: core.Input }],
        enter: [{ type: core.Input }],
        enterFrom: [{ type: core.Input }],
        enterTo: [{ type: core.Input }],
        leave: [{ type: core.Input }],
        leaveFrom: [{ type: core.Input }],
        leaveTo: [{ type: core.Input }],
        beforeEnter: [{ type: core.Output }],
        afterEnter: [{ type: core.Output }],
        beforeLeave: [{ type: core.Output }],
        afterLeave: [{ type: core.Output }],
        getDisplay: [{ type: core.HostBinding, args: ['style.display',] }]
    };

    var TransitionModule = /** @class */ (function () {
        function TransitionModule() {
        }
        return TransitionModule;
    }());
    TransitionModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [TransitionComponent],
                    imports: [
                        common.CommonModule
                    ],
                    exports: [TransitionComponent]
                },] }
    ];

    /*
     * Public API Surface of ngx-headlessui
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.MenuButtonDirective = MenuButtonDirective;
    exports.MenuComponent = MenuComponent;
    exports.MenuItemComponent = MenuItemComponent;
    exports.MenuItemsDirective = MenuItemsDirective;
    exports.MenuModule = MenuModule;
    exports.SwitchComponent = SwitchComponent;
    exports.SwitchDescriptionDirective = SwitchDescriptionDirective;
    exports.SwitchGroupDirective = SwitchGroupDirective;
    exports.SwitchLabelDirective = SwitchLabelDirective;
    exports.SwitchModule = SwitchModule;
    exports.TransitionComponent = TransitionComponent;
    exports.TransitionModule = TransitionModule;
    exports.transition = transition;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-headlessui.umd.js.map
